# Step 6: Start Modernization
### On this page
  * [Visualize Changes with Reports](https://help.sap.com/docs/leanix/ea/application-modernization-start-initiative#visualize-changes-with-reports)
  * [Execute Transformations in an Initiative](https://help.sap.com/docs/leanix/ea/application-modernization-start-initiative#execute-transformations-in-an-initiative)
  * [Execute Transformations in Bulk with the Transformations Explorer](https://help.sap.com/docs/leanix/ea/application-modernization-start-initiative#execute-transformations-in-bulk-with-the-transformations-explorer)


Visualize and evaluate target architecture to help identify impacted applications and necessary technical changes.
After you add your transformations and create your roadmap, it’s time to kick off your modernization. You can visualize and evaluate your target architecture using reports in SAP LeanIX Architecture and Road Map Planning. Use them to see how many applications are impacted, identify where technical changes are needed, and determine how many applications can be decommissioned.
